@@ -19,7 +19,7 @@ def pixel(x, y):
         im = Pasteboard().get_contents(TIFF)
         im = Image.open(BytesIO(im))
         return (im.getpixel((0,0)))
-    elif (platform == "win32" or os.platform == "linux" or os.platform == "linux2"):
+    elif (platform == "win32" or platform == "linux" or platform == "linux2"):
         im = pyautogui.screenshot(region=(x,y,1,1))
         return (im.getpixel((0,0)))
     else:
